@@ -17,6 +17,7 @@
 # You should have received a copy of the GNU General Public License
 # along with mb-netmgmt. If not, see <https://www.gnu.org/licenses/
 
+import logging
 from socketserver import BaseRequestHandler
 from socketserver import TCPServer as Server
 
@@ -31,12 +32,11 @@ from ncclient.transport.session import (
     qualify,
     sub_ele,
     to_ele,
-    new_ele,
 )
 from ncclient.transport.ssh import MSG_DELIM, PORT_NETCONF_DEFAULT, SSHSession
 
 from mb_netmgmt.__main__ import Protocol
-from mb_netmgmt.ssh import accept
+from mb_netmgmt.ssh import start_server
 
 stopped = False
 
@@ -50,10 +50,12 @@ class Handler(BaseRequestHandler, Protocol):
 
     def handle(self):
         self.callback_url = self.server.callback_url
-        self.channel = accept(self.request)
+        transport = start_server(self.request)
+        self.channel = transport.accept()
         self.open_upstream()
         self.session._connected = True
         self.handle_prompt()
+        self.session._transport = transport
         self.session._channel = self.channel
         self.session.run()
 
@@ -87,17 +89,16 @@ class Handler(BaseRequestHandler, Protocol):
             if "urn:ietf:params:netconf:base:1.1" in capabilities:
                 self.session._base = NetconfBase.BASE_11
 
-        self.session.add_listener(HelloHandler(init_cb, None))
+        self.session.add_listener(HelloHandler(init_cb, logging.error))
 
     def read_proxy_response(self):
-        rpc_reply = self.rpc_reply._root[0]
-        return {"rpc-reply": to_xml(rpc_reply)}
+        return {"rpc-reply": unwrap_proxy_response(self.rpc_reply._root)}
 
     def send_upstream(self, request, request_id):
         self.rpc_reply = self.manager.rpc(to_ele(request["rpc"]))
 
     def respond(self, response, request_id):
-        message = wrap_reply(to_ele(response["rpc-reply"]), request_id)
+        message = wrap_reply(response["rpc-reply"], request_id)
         self.session.send(message)
 
 
@@ -113,11 +114,19 @@ class Listener(SessionListener):
         request = {"rpc": to_xml(ele[0])}
         self.handle_request(request, attrs["message-id"])
 
+    def errback(self, ex):
+        logging.error(ex)
 
-def wrap_reply(subele, message_id):
-    ele = new_ele("rpc-reply", {"message-id": message_id})
-    ele.append(subele)
-    return to_xml(ele)
+
+def wrap_reply(rpc_reply, message_id):
+    return f'<nc:rpc-reply xmlns:nc="urn:ietf:params:xml:ns:netconf:base:1.0" message-id="{message_id}">{rpc_reply}</nc:rpc-reply>'
+
+
+def unwrap_proxy_response(root):
+    try:
+        return to_xml(root[0])
+    except IndexError:
+        return root.text
 
 
 def to_xml(ele):
